# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
   This script automates the installation, execution, and
   results parsing for the tiobench test suite.
   tiobench is a multi-threaded I/O benchmark. It is used to measure
   file system performance in four basic operations: sequential read,
   random read, sequential write, and random write.
"""
import re

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test


VERSION="0.3.3"
URL="http://prdownloads.sourceforge.net/tiobench/tiobench-%s.tar.gz" %(VERSION)
MD5="bf485bf820e693c79e6bd2a38702a128"
DEFAULT_OPTIONS = "--block=4096 --block=8192 --threads=2 --numruns=2"
INSTALLSTEPS = ['tar -zxvf tiobench-%s.tar.gz' % VERSION,
                'cd tiobench-%s && make' % VERSION]
RUNSTEPS = ["cd tiobench-%s && "\
            "./tiobench.pl $(OPTIONS)" % (VERSION)]


class TIObenchTestParser(TestParser):
    def parse(self, artifacts):
        # Pattern to match the test case name
        pattern1="(?P<test_id>^(Sequential|Random) (Writes|Reads))"
        # Pattern to match the parameter details and measurement
        pattern2=".*?(?P<file_size>\d+)\s+(?P<blks_size>\d+)\s+.*?  "\
                 "(?P<measurement>((\d|#)+\.?\d*))"
        filename = "testoutput.log"
        pat1 = re.compile(pattern1)
        pat2 = re.compile(pattern2)
        tc_id = None
        with open(filename) as fd:
            for lineno, line in enumerate(fd, 1):
                match1 = pat1.match(line)
                match2 = pat2.search(line)
                if match1:
                    tc_id = match1.group('test_id').replace(" ", "")
                if match2 and tc_id != None:
                    results = match2.groupdict()
                    blks_size = results.pop('blks_size')
                    filesize = results.pop('file_size')
                    results['test_case_id'] = (
                        '%s_%sMBfilesize_%sbytesblksize') % (
                            tc_id, filesize, blks_size)
                    results["log_filename"] = "testoutput.log"
                    results["log_lineno"] = lineno
                    self.results['test_results'].append(
                        self.analyze_test_result(results))

tiobench_inst = TestInstaller(INSTALLSTEPS, url=URL,
    md5=MD5)
tiobench_run = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
parse = TIObenchTestParser(appendall={'units':'MB/s', 'result':'pass'})
testobj = Test(test_id="tiobench", test_version=VERSION,
    installer=tiobench_inst, runner=tiobench_run, parser=parse)



# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
   This script automates the automate installation, execution, and
   results parsing for the Pybench test suite.
   The Pybench test Suite is an open source test suite that provides a
   standardized way to measure the performance of Python implementations.
"""


from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test


VERSION='r27'
URL="http://svn.python.org/projects/python/tags/%s/Tools/pybench/" %(VERSION)
DEFAULT_OPTIONS = ""
INSTALLSTEPS = ["svn export %s" %(URL)]
RUNSTEPS = ['python pybench/pybench.py $(OPTIONS)']
DEPS = ['subversion']

my_installer = TestInstaller(INSTALLSTEPS, deps=DEPS)
my_runner = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)

# test case name is first column and measurement is average column
#
#Test                             minimum  average  operation  overhead
#         BuiltinFunctionCalls:     85ms    151ms    0.30us    0.147ms
#         BuiltinMethodLookup:      68ms    113ms    0.11us    0.171ms

PATTERN = "^\s+(?P<test_case_id>\w+):\s+(\d+)ms\s+(?P<measurement>\d+)ms"

my_parser = TestParser(PATTERN, appendall={'units':'ms','result':'pass'})

testobj = Test(test_id="pybench", installer=my_installer,
               runner=my_runner, parser=my_parser)



# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Bootchart is a benchmark for measuring the time it takes to boot the system 
to a point where it hands over control to the user.

**URL:** http://bootchart.org

**Default options:** None
"""


from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

DEFAULT_OPTIONS = ""
INSTALLSTEPS = ['bzr branch lp:~linaro-foundations/lava-test/bootchartscript']
DEPS = ['bootchart', 'pybootchartgui', 'bzr']
RUNSTEPS = ['./bootchartscript/bootchartscript.sh $(OPTIONS)']
PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+\.\d+)"

bootchartinst = TestInstaller(INSTALLSTEPS, deps=DEPS)
bootchartrun = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
bootchartparser = TestParser(PATTERN,
                   appendall={'units':'sec', 'result':'pass'})
testobj = Test(test_id="bootchart", installer=bootchartinst,
                                  runner=bootchartrun, parser=bootchartparser)



# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
GLMemPerf is an OpenGL ES 2.0 performance estimation tool that aims to
measure the memory bandwidth characteristics of a graphics implementation.
It performs a number of blit style renders using different texture formats,
sizes, orientations and fragment shaders. The results are given as frames
per second numbers.

**URL:** http://gitorious.org/meego-graphics/glmemperf

**Default Options:** -e shimage
"""


from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

DEFAULT_OPTIONS = "-e shmimage"
RUNSTEPS = ["glmemperf $(OPTIONS)"]
PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+) fps"

inst = TestInstaller(deps=["glmemperf"])
run = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
parse = TestParser(PATTERN,
                                      appendall={'units':'fps',
                                                 'result':'pass'})

testobj = Test(test_id="glmemperf", installer=inst,
                                  runner=run, parser=parse)



# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging
import logging.config

from  lava_test.core.config import get_config

from lava_tool.dispatcher import LavaDispatcher, run_with_dispatcher_class


class LAVATestDispatcher(LavaDispatcher):

    toolname = 'lava_test'
    description = """
    LAVA Test wrapper framework
    """
    epilog = """
    Please report all bugs using the Launchpad bug tracker:
    http://bugs.launchpad.net/lava-test/+filebug
    """


def main():

    logging_config_file = get_config().get_logging_config_file()

    if logging_config_file != None:
        logging.config.fileConfig(logging_config_file)
    else:
        # config the python logging
       FORMAT = '<LAVA_TEST>%(asctime)s %(levelname)s: %(message)s'
       DATEFMT= '%Y-%m-%d %I:%M:%S %p'
       logging.basicConfig(format=FORMAT,datefmt=DATEFMT)
       logging.root.setLevel(logging.DEBUG)

    run_with_dispatcher_class(LAVATestDispatcher)


if __name__ == '__main__':
    import os
    import sys
    arg_only = sys.argv
    arg_only.remove(arg_only[0])
    code = LAVATestDispatcher().dispatch(arg_only)
    if (code != 0): exit(code)


# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

DEFAULT_OPTIONS = ""
DEPS = ["linux-tools"]
RUNSTEPS = ["export PERFBIN=`find /usr/bin/ -name perf_* | sort -r | head -n 1 | xargs basename`; $PERFBIN test 2>&1  $(OPTIONS)"]
PATTERN = "^ \d+:\s+(?P<test_case_id>[\w\s]+):\W+(?P<message>\w+)"

perfinst = TestInstaller(deps=DEPS)
perfrun = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
perfparser = TestParser(PATTERN,
                   appendall={"result":"pass"})
testobj = Test(test_id="perf", installer=perfinst,
                                  runner=perfrun, parser=perfparser)



# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
   This script automates the automate installation, execution, and
   results parsing for the OpenPosix test suite.
   The POSIX Test Suite is an open source test suite with the goal of
   performing conformance, functional, and stress testing of the IEEE
   1003.1-2001 System Interfaces specification However the automation here
   does not support the stress test runs.

"""
import re

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test


VERSION="20100831"
URL= "http://downloads.sourceforge.net/project/ltp/LTP Source/ltp-%s/"\
     "ltp-full-%s.bz2" % (VERSION, VERSION)
MD5="6982c72429a62f3917c13b2d529ad1ce"
DEFAULT_OPTIONS = ""
INSTALLSTEPS = ['tar -xjf ltp-full-20100831.bz2']
DEPS = ['gcc', 'bzip2']
RUNSTEPS = ['cd ltp-full-20100831/testcases/open_posix_testsuite/ && make $(OPTIONS)']

PATTERN = "((?P<test_case_id>\A(\w+[/]+)+\w+[-]*\w*[-]*\w*) .*? (?P<result>\w+))"
FIXUPS = {
            "FAILED"      :  "fail",
            "INTERRUPTED" :  "skip",
            "PASSED"      :  "pass",
            "UNRESOLVED"  :  "unknown",
            "UNSUPPORTED" :  "skip",
            "UNTESTED"    :  "skip",
            "SKIPPING"    :  "skip"
         }


class PosixParser(TestParser):
    def parse(self, artifacts):
        filename = "testoutput.log"
        pat = re.compile(self.pattern)
        with open(filename) as fd:
            for lineno, line in enumerate(fd, 1):
                match = pat.match(line)
                if not match:
                    continue
                results = match.groupdict()
                test_case_id = results['test_case_id']
                results['test_case_id'] = test_case_id.replace("/", ".")
                results["log_filename"] = "testoutput.log"
                results["log_lineno"] = lineno
                self.results['test_results'].append(
                    self.analyze_test_result(results))

posix_inst = TestInstaller(INSTALLSTEPS, deps=DEPS,
    url=URL, md5=MD5)
posix_run = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
posixparser = PosixParser(PATTERN, fixupdict = FIXUPS)
testobj = Test(test_id="posixtestsuite", test_version=VERSION,
                                  installer=posix_inst, runner=posix_run,
                                  parser=posixparser)



# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

DEFAULT_OPTIONS = ""
RUNSTEPS = ['smem -w $(OPTIONS) | tail -n 3']
PATTERN = "^(?P<test_case_id>(\w+\s)+)\s\s+(?P<measurement>\d+)"
DEPS = ['smem']


smeminst = TestInstaller(deps=DEPS)
smemrun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
smemparser = TestParser(PATTERN,
               appendall={'units':'KB', 'result':'pass'})
testobj = Test(test_id="smem", installer=smeminst,
                                  runner=smemrun, parser=smemparser)
